#ifndef _OBJCONVERTER_H
#define _OBJCONVERTER_H

#include "SimpleVec.h"
#include <string>
#include <vector>
#include <map>


struct Material
{
	float rgb[3];
	int texture;
};

class Geometry;

typedef std::vector<SimpleVec> VertexArray;
typedef std::pair<float, float> Texcoord;
typedef std::map<std::string, Material *> MaterialTable;
typedef std::map<std::string, int> TextureTable;

typedef std::vector<std::string> TextureArray;

class ogzstream;

/** Converts obj format into objects readable by our format
*/
class ObjConverter
{
public:

	ObjConverter();

	bool Convert(const std::string &inputFilename, 
		         const std::string &outputFilename);
	             // const std::string textureFilename) const;

	bool LoadMaterials(const std::string &matFileName);

	~ObjConverter();

protected:

	struct Geometry
	{
		SimpleVec *mVertices;
		SimpleVec *mNormals;
		Texcoord *mTexcoords;
		Material *mMaterial;

		int mVertexCount;
		int mTexcoordCount;
	};

typedef std::vector<Geometry *> GeometryArray;

	void LoadShape(const VertexArray &faceVertices,
		           const VertexArray &faceNormals,
				   const std::vector<Texcoord> &faceTexcoords, 
				   Material *mat);

	void WriteGeometry(ogzstream &str, Geometry *geom);

	bool ReadFile(const std::string &inputFilename);
	bool WriteFile(const std::string &outputFilename);


	MaterialTable mMaterialTable;
	TextureTable mTextureTable;
	
	TextureArray mTextures;
	GeometryArray mGeometry;

	int mNumShapes;
};



#endif
